@@ -83,9 +83,6 @@ class IncidenceAttachmentModelPrivate
 
     void resetInternalData()
     {
-        if (m_incidence) {
-            m_incidence->clearTempFiles();
-        }
         Item item = m_item;
         if (m_modelIndex.isValid()) {
             item = m_modelIndex.data(EntityTreeModel::ItemRole).value<Akonadi::Item>();
@@ -191,16 +188,14 @@ QVariant IncidenceAttachmentModel::data(const QModelIndex &index, int role) cons
         return QVariant();
     }
 
-    KCalCore::Attachment::Ptr attachment = d->m_incidence->attachments().at(index.row());
+    const KCalCore::Attachment attachment = d->m_incidence->attachments().at(index.row());
     switch (role) {
     case Qt::DisplayRole:
-        return attachment->label();
+        return attachment.label();
     case AttachmentDataRole:
-        return attachment->decodedData();
+        return attachment.decodedData();
     case MimeTypeRole:
-        return attachment->mimeType();
-    case AttachmentUrl:
-        return d->m_incidence->writeAttachmentToTempFile(attachment);
+        return attachment.mimeType();
     }
     return QVariant();
 }
@@ -215,7 +210,6 @@ QHash<int, QByteArray> CalendarSupport::IncidenceAttachmentModel::roleNames() co
 {
     QHash<int, QByteArray> roleNames = QAbstractListModel::roleNames();
     roleNames.insert(IncidenceAttachmentModel::MimeTypeRole, "mimeType");
-    roleNames.insert(IncidenceAttachmentModel::AttachmentUrl, "attachmentUrl");
     return roleNames;
 }
 
