@@ -395,7 +395,7 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
         QRect organizerBox(timesBox.left() + padding(), h + padding(),
                            timesBox.right() - padding(), lineHeight);
         h = qMax(printCaptionAndText(p, organizerBox, i18n("Organizer: "),
-                                     (*it)->organizer()->fullName(), captionFont, textFont), h);
+                                     (*it)->organizer().fullName(), captionFont, textFont), h);
 
         // Finally, draw the frame around the time information...
         timesBox.setBottom(qMax(timesBox.bottom(), h + padding()));
@@ -587,7 +587,7 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
                 if (!attachmentString.isEmpty()) {
                     attachmentString += i18nc("Spacer for list of attachments", "  ");
                 }
-                attachmentString.append((*ait)->label());
+                attachmentString.append((*ait).label());
             }
             drawBoxWithCaption(p, attachmentsBox,
                                attachmentCaption, attachmentString,
@@ -615,9 +615,9 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
                     "'Name (Role): Status', e.g. 'Reinhold Kainhofer "
                     "<reinhold@kainhofer.com> (Participant): Awaiting Response'",
                     "%1 (%2): %3",
-                    (*ait)->fullName(),
-                    KCalUtils::Stringify::attendeeRole((*ait)->role()),
-                    KCalUtils::Stringify::attendeeStatus((*ait)->status()));
+                    (*ait).fullName(),
+                    KCalUtils::Stringify::attendeeRole((*ait).role()),
+                    KCalUtils::Stringify::attendeeStatus((*ait).status()));
             }
             drawBoxWithCaption(p, attendeesBox, attendeeCaption, attendeeString,
                                /*sameLine=*/ false, /*expand=*/ false,
